@@ -563,6 +563,22 @@ VARIABLES = {
     "sfc_categorical_ice": Variable(long_name="", dtype=Dtype.SHORT),
     "sfc_categorical_freezing_rain": Variable(long_name="", dtype=Dtype.SHORT),
     "sfc_categorical_rain": Variable(long_name="", dtype=Dtype.SHORT),
+    "sfc_albedo_sw_direct": Variable(
+        long_name="Surface albedo (shortwave direct)",
+        # standard_name="surface_albedo_shortwave_direct",
+    ),
+    "sfc_albedo_sw_diffuse": Variable(
+        long_name="Surface albedo (shortwave diffuse)",
+        # standard_name="surface_albedo_shortwave_diffuse",
+    ),
+    "sfc_albedo_lw_direct": Variable(
+        long_name="Surface albedo (longwave direct)",
+        # standard_name="surface_albedo_longwave_direct",
+    ),
+    "sfc_albedo_lw_diffuse": Variable(
+        long_name="Surface albedo (longwave diffuse)",
+        # standard_name="surface_albedo_longwave_diffuse",
+    ),
     "nfft": Variable(long_name="Number of FFT points", dtype=Dtype.INT),
     "nave": Variable(
         long_name="Number of spectral averages (not accounting for overlapping FFTs)",
@@ -580,4 +596,10 @@ VARIABLES = {
     "radar_roll": Variable(
         long_name="Radar roll angle", units="degree", standard_name="platform_roll"
     ),
+    "zdr": Variable(long_name="Differential reflectivity", units="dB"),
+    "rho_hv": Variable(long_name="Correlation coefficient"),
+    "phi_dp": Variable(long_name="Differential phase", units="rad"),
+    "srho_hv": Variable(long_name="Slanted correlation coefficient"),
+    "kdp": Variable(long_name="Specific differential phase shift", units="rad km-1"),
+    "differential_attenuation": Variable(long_name="Differential attenuation", units="dB km-1"),
 }
